@@ -29,10 +29,6 @@
 #include "pango-language.h"
 #include "pango-impl-utils.h"
 
-#ifdef HAVE_CORE_TEXT
-#include <CoreFoundation/CoreFoundation.h>
-#endif /* HAVE_CORE_TEXT */
-
 
 /* We embed a private struct right *before* a where a PangoLanguage *
  * points to.
@@ -66,7 +62,7 @@ pango_language_get_private (PangoLanguage *language)
   if (!language)
     return NULL;
 
-  priv = (PangoLanguagePrivate *)(void *)((char *)language - sizeof (PangoLanguagePrivate));
+  priv = (PangoLanguagePrivate *) ((char *)language - sizeof (PangoLanguagePrivate));
 
   if (G_UNLIKELY (priv->magic != PANGO_LANGUAGE_PRIVATE_MAGIC))
     {
@@ -133,15 +129,6 @@ pango_language_free (PangoLanguage *language G_GNUC_UNUSED)
   return; /* nothing */
 }
 
-/**
- * PangoLanguage:
- *
- * The #PangoLanguage structure is used to
- * represent a language.
- *
- * #PangoLanguage pointers can be efficiently
- * copied and compared with each other.
- */
 G_DEFINE_BOXED_TYPE (PangoLanguage, pango_language,
                      pango_language_copy,
                      pango_language_free);
@@ -201,51 +188,8 @@ _pango_get_lc_ctype (void)
     return g_strdup (p);
 
   return g_win32_getlocale ();
-#elif defined(HAVE_CORE_TEXT)
-  CFArrayRef languages;
-  CFStringRef language;
-  gchar ret[16];
-  gchar *p;
-
-  /* Take the same approach as done for Windows above. First we check
-   * if somebody tried to set the locale through environment variables.
-   */
-  p = getenv ("LC_ALL");
-  if (p != NULL)
-    return g_strdup (p);
-
-  p = getenv ("LC_CTYPE");
-  if (p != NULL)
-    return g_strdup (p);
-
-  p = getenv ("LANG");
-  if (p != NULL)
-    return g_strdup (p);
-
-  /* If the environment variables are not set, determine the locale
-   * through the platform-native API.
-   */
-  languages = CFLocaleCopyPreferredLanguages ();
-  language = CFArrayGetValueAtIndex (languages, 0);
-
-  if (!CFStringGetCString (language, ret, 16, kCFStringEncodingUTF8))
-    {
-      CFRelease (languages);
-      return g_strdup (setlocale (LC_CTYPE, NULL));
-    }
-
-  CFRelease (languages);
-
-  return g_strdup (ret);
 #else
-  {
-    gchar *lc_ctype = setlocale (LC_CTYPE, NULL);
-
-    if (lc_ctype)
-      return g_strdup (lc_ctype);
-    else
-      return g_strdup ("C");
-  }
+  return g_strdup (setlocale (LC_CTYPE, NULL));
 #endif
 }
 
@@ -279,26 +223,21 @@ _pango_get_lc_ctype (void)
  * functions automatically (by calling gtk_set_locale()).
  * See <literal>man setlocale</literal> for more details.
  *
- * Return value: (transfer none): the default language as a
- *               #PangoLanguage, must not be freed.
+ * Return value: the default language as a #PangoLanguage, must not be
+ *               freed.
  *
  * Since: 1.16
  **/
 PangoLanguage *
 pango_language_get_default (void)
 {
-  static PangoLanguage *result = NULL; /* MT-safe */
+  static PangoLanguage *result = NULL;
 
-  if (g_once_init_enter (&result))
+  if (G_UNLIKELY (!result))
     {
-      gchar *lc_ctype;
-      PangoLanguage *lang;
-
-      lc_ctype = _pango_get_lc_ctype ();
-      lang = pango_language_from_string (lc_ctype);
-      g_free (lc_ctype);
-
-      g_once_init_leave (&result, lang);
+      gchar *lang = _pango_get_lc_ctype ();
+      result = pango_language_from_string (lang);
+      g_free (lang);
     }
 
   return result;
@@ -320,16 +259,14 @@ pango_language_get_default (void)
  * Use pango_language_get_default() if you want to get the #PangoLanguage for
  * the current locale of the process.
  *
- * Return value: (transfer none) (nullable): an opaque pointer to a
- *               #PangoLanguage structure, or %NULL if @language was
- *               %NULL.  The returned pointer will be valid forever
- *               after, and should not be freed.
+ * Return value: an opaque pointer to a #PangoLanguage structure, or %NULL
+ *               if @language was %NULL.  The returned pointer will be valid
+ *               forever after, and should not be freed.
  **/
 PangoLanguage *
 pango_language_from_string (const char *language)
 {
-  G_LOCK_DEFINE_STATIC (lang_from_string);
-  static GHashTable *hash = NULL; /* MT-safe */
+  static GHashTable *hash = NULL;
   PangoLanguagePrivate *priv;
   char *result;
   int len;
@@ -338,15 +275,13 @@ pango_language_from_string (const char *language)
   if (language == NULL)
     return NULL;
 
-  G_LOCK (lang_from_string);
-
   if (G_UNLIKELY (!hash))
     hash = g_hash_table_new (lang_hash, lang_equal);
   else
     {
       result = g_hash_table_lookup (hash, language);
       if (result)
-        goto out;
+	return (PangoLanguage *)result;
     }
 
   len = strlen (language);
@@ -364,9 +299,6 @@ pango_language_from_string (const char *language)
 
   g_hash_table_insert (hash, result, result);
 
-out:
-  G_UNLOCK (lang_from_string);
-
   return (PangoLanguage *)result;
 }
 
@@ -387,7 +319,7 @@ const char *
 
 /**
  * pango_language_matches:
- * @language: (nullable): a language tag (see pango_language_from_string()),
+ * @language: a language tag (see pango_language_from_string()),
  *            %NULL is allowed and matches nothing but '*'
  * @range_list: a list of language ranges, separated by ';', ':',
  *   ',', or space characters.
@@ -519,6 +451,12 @@ find_best_lang_match_cached (PangoLanguage *language,
   return result;
 }
 
+#define FIND_BEST_LANG_MATCH(language, records) \
+	find_best_lang_match ((language), \
+			      records, \
+			      G_N_ELEMENTS (records), \
+			      sizeof (*records));
+
 #define FIND_BEST_LANG_MATCH_CACHED(language, cache_key, records) \
 	find_best_lang_match_cached ((language), \
 				     pango_language_get_private (language) ? \
@@ -561,7 +499,7 @@ static const LangInfo lang_texts[] = {
 
 /**
  * pango_language_get_sample_string:
- * @language: (nullable): a #PangoLanguage, or %NULL
+ * @language: a #PangoLanguage, or %NULL
  *
  * Get a string that is representative of the characters needed to
  * render a particular language.
@@ -638,16 +576,12 @@ pango_language_get_sample_string (PangoLanguage *language)
  * The pango_language_includes_script() function uses this function
  * internally.
  *
- * Note: while the return value is declared as PangoScript, the
- * returned values are from the GUnicodeScript enumeration, which
- * may have more values. Callers need to handle unknown values.
- *
- * Return value: (array length=num_scripts) (nullable): An array of
- * #PangoScript values, with the number of entries in the array stored
- * in @num_scripts, or %NULL if Pango does not have any information
- * about this particular language tag (also the case if @language is
- * %NULL).  The returned array is owned by Pango and should not be
- * modified or freed.
+ * Return value: An array of #PangoScript values, with the
+ * number of entries in the array stored in @num_scripts, or
+ * %NULL if Pango does not have any information about this
+ * particular language tag (also the case if @language is %NULL).
+ * The returned array is owned by Pango and should not be modified
+ * or freed.
  
  * Since: 1.22
  **/
@@ -662,7 +596,7 @@ pango_language_get_scripts (PangoLanguage *language,
 						 script_for_lang,
 						 pango_script_for_lang);
 
-  if (!script_for_lang || script_for_lang->scripts[0] == 0)
+  if (!script_for_lang)
     {
       if (num_scripts)
 	*num_scripts = 0;
@@ -681,12 +615,12 @@ pango_language_get_scripts (PangoLanguage *language,
       *num_scripts = j;
     }
 
-  return (const PangoScript *) script_for_lang->scripts;
+  return script_for_lang->scripts;
 }
 
 /**
  * pango_language_includes_script:
- * @language: (nullable): a #PangoLanguage, or %NULL
+ * @language: a #PangoLanguage, or %NULL
  * @script: a #PangoScript
  *
  * Determines if @script is one of the scripts used to
@@ -794,14 +728,11 @@ parse_default_languages (void)
 static PangoLanguage *
 _pango_script_get_default_language (PangoScript script)
 {
-  G_LOCK_DEFINE_STATIC (languages);
-  static gboolean initialized = FALSE; /* MT-safe */
-  static PangoLanguage * const * languages = NULL; /* MT-safe */
-  static GHashTable *hash = NULL; /* MT-safe */
+  static gboolean initialized = FALSE;
+  static PangoLanguage * const * languages = NULL;
+  static GHashTable *hash = NULL;
   PangoLanguage *result, * const * p;
 
-  G_LOCK (languages);
-
   if (G_UNLIKELY (!initialized))
     {
       languages = parse_default_languages ();
@@ -813,13 +744,10 @@ _pango_script_get_default_language (PangoScript script)
     }
 
   if (!languages)
-    {
-      result = NULL;
-      goto out;
-    }
+    return NULL;
 
   if (g_hash_table_lookup_extended (hash, GINT_TO_POINTER (script), NULL, (gpointer *) (gpointer) &result))
-    goto out;
+    return result;
 
   for (p = languages; *p; p++)
     if (pango_language_includes_script (*p, script))
@@ -828,9 +756,6 @@ _pango_script_get_default_language (PangoScript script)
 
   g_hash_table_insert (hash, GINT_TO_POINTER (script), result);
 
-out:
-  G_UNLOCK (languages);
-
   return result;
 }
 
@@ -869,7 +794,7 @@ out:
  * choose a default language for %PANGO_SCRIPT_HAN when setting
  * context language is not feasible.
  *
- * Return value: (nullable): a #PangoLanguage that is representative
+ * Return value: a #PangoLanguage that is representative
  * of the script, or %NULL if no such language exists.
  *
  * Since: 1.4
@@ -963,34 +888,7 @@ pango_script_get_sample_language (PangoScript script)
     "",    /* PANGO_SCRIPT_CUNEIFORM */
     "",    /* PANGO_SCRIPT_PHOENICIAN */
     "",    /* PANGO_SCRIPT_PHAGS_PA */
-    "nqo", /* PANGO_SCRIPT_NKO */
-
-    /* Unicode-5.1 additions */
-    "",    /* PANGO_SCRIPT_KAYAH_LI */
-    "",    /* PANGO_SCRIPT_LEPCHA */
-    "",    /* PANGO_SCRIPT_REJANG */
-    "",    /* PANGO_SCRIPT_SUNDANESE */
-    "",    /* PANGO_SCRIPT_SAURASHTRA */
-    "",    /* PANGO_SCRIPT_CHAM */
-    "",    /* PANGO_SCRIPT_OL_CHIKI */
-    "",    /* PANGO_SCRIPT_VAI */
-    "",    /* PANGO_SCRIPT_CARIAN */
-    "",    /* PANGO_SCRIPT_LYCIAN */
-    "",    /* PANGO_SCRIPT_LYDIAN */
-
-    /* Unicode-6.0 additions */
-    "",    /* PANGO_SCRIPT_BATAK */
-    "",    /* PANGO_SCRIPT_BRAHMI */
-    "",    /* PANGO_SCRIPT_MANDAIC */
-
-    /* Unicode-6.1 additions */
-    "",    /* PANGO_SCRIPT_CHAKMA */
-    "",    /* PANGO_SCRIPT_MEROITIC_CURSIVE */
-    "",    /* PANGO_SCRIPT_MEROITIC_HIEROGLYPHS */
-    "",    /* PANGO_SCRIPT_MIAO */
-    "",    /* PANGO_SCRIPT_SHARADA */
-    "",    /* PANGO_SCRIPT_SORA_SOMPENG */
-    "",    /* PANGO_SCRIPT_TAKRI */
+    "nqo"  /* PANGO_SCRIPT_NKO */
   };
   const char *sample_language;
   PangoLanguage *result;
